﻿function find_config($project) {
	$configPath = $null

	if ($project -eq $null -or $project.ProjectItems -eq $null) {
		return $configPath
	}

	$config = $project.ProjectItems.Item("Web.config")

	if ($config -eq $null) {
		$config = $project.ProjectItems.Item("App.config")
	}

	if ($config -ne $null) {
		$configPath = $config.Properties.Item("LocalPath").Value
	}

	return $configPath
}

function update_config($configPath, $platform) {
	[xml] $configXml = gc $configPath
    
	if ($configXml -ne $null) {
		$configSection = $configXml.SelectSingleNode("configuration/configSections/section[@name='exceptionless']")
		if ($configSection -eq $null) {
			$parentNode = $configXml.SelectSingleNode("configuration/configSections")
			if ($parentNode -eq $null) {
				$parentNode = $configXml.configuration.AppendChild($configXml.CreateElement('configSections'))
			}
			$configSection = $configXml.CreateElement('section')
			$configSection.SetAttribute('name', 'exceptionless')
			$configSection.SetAttribute('type', 'Exceptionless.Configuration.ExceptionlessSection, Exceptionless')
			
			$parentNode.AppendChild($configSection)
		}
		
		if ($configXml.SelectSingleNode("configuration/exceptionless") -eq $null) {
			$exceptionlessNode = $configXml.CreateElement('exceptionless')
			$exceptionlessNode.SetAttribute('apiKey', 'API_KEY_HERE')
			
			$target = $configXml.configuration['system.web']
			$configXml.configuration.InsertBefore($exceptionlessNode, $target)
		}
		
		if ($platform -ne $null) {
			$webModule = $configXml.SelectSingleNode("configuration/system.web/httpModules/add[@name='ExceptionlessModule']")
			if ($webModule -eq $null) {
				$parentNode = $configXml.SelectSingleNode("configuration/system.web")
				if ($parentNode -eq $null) {
					$parentNode = $configXml.configuration.AppendChild($configXml.CreateElement('system.web'))
				}
				$parentNode = $configXml.SelectSingleNode("configuration/system.web/httpModules")
				if ($parentNode -eq $null) {
					$parentNode = $configXml.configuration['system.web'].AppendChild($configXml.CreateElement('httpModules'))
				}
				$webModule = $configXml.CreateElement('add')
				$webModule.SetAttribute('name', 'ExceptionlessModule')
				$webModule.SetAttribute('type', 'Exceptionless.' + $platform + '.ExceptionlessModule, Exceptionless.' + $platform)
				
				$parentNode.AppendChild($webModule)
			}
			
			$webServerModule = $configXml.SelectSingleNode("configuration/system.webServer/modules/add[@name='ExceptionlessModule']")
			if ($webServerModule -eq $null) {
				$parentNode = $configXml.SelectSingleNode("configuration/system.webServer")
				if ($parentNode -eq $null) {
					$parentNode = $configXml.configuration.AppendChild($configXml.CreateElement('system.webServer'))
				}
				$parentNode = $configXml.SelectSingleNode("configuration/system.webServer/modules")
				if ($parentNode -eq $null) {
					$parentNode = $configXml.configuration['system.webServer'].AppendChild($configXml.CreateElement('modules'))
				}
				$webServerModule = $configXml.CreateElement('add')
				$webServerModule.SetAttribute('name', 'ExceptionlessModule')
				$webServerModule.SetAttribute('type', 'Exceptionless.' + $platform + '.ExceptionlessModule, Exceptionless.' + $platform)
				
				$parentNode.AppendChild($webServerModule)
			}
		}
		
		$configXml.Save($configPath)
	}
}

function remove_config($configPath) {
	[xml] $configXml = gc $configPath
    
	if ($configXml -ne $null) {
		$configSection = $configXml.SelectSingleNode("configuration/configSections/section[@name='exceptionless']")
		if ($configSection -ne $null) {
			[Void]$configSection.ParentNode.RemoveChild($configSection)
		}
		
		$configSection = $configXml.SelectSingleNode("configuration/exceptionless")
		if ($configSection -ne $null) {
			if ($configSection.HasAttribute("apiKey") -and ($configSection.GetAttribute("apiKey") -ne 'API_KEY_HERE') -and ($configSection.GetAttribute("apiKey").length -gt 10)) {
				"Exceptionless API Key has been configured and will not be removed."
			} else {
				[Void]$configSection.ParentNode.RemoveChild($configSection)
			}
		}
		
		$webModule = $configXml.SelectSingleNode("configuration/system.web/httpModules/add[@name='ExceptionlessModule']")
		if ($webModule -ne $null) {
			[Void]$webModule.ParentNode.RemoveChild($webModule)
		}
		
		$webServerModule = $configXml.SelectSingleNode("configuration/system.webServer/modules/add[@name='ExceptionlessModule']")
		if ($webServerModule -ne $null) {
			[Void]$webServerModule.ParentNode.RemoveChild($webServerModule)
		}
		
		$configXml.Save($configPath)
	}
}

function add_attribute($sourceFile) {
	if (!(test-path $sourceFile)) {
	    return
	}
	
	$input = get-content $sourceFile
	$isUpdated = $input | Select-String "Exceptionless" -quiet
	
	if ($isUpdated) {
	   return
	}
	
	# seems to insure a linefeed
	"" | Out-file $sourceFile -append
	if ([string]$sourceFile.EndsWith('.vb')) {
		'<assembly: Exceptionless.Configuration.Exceptionless("API_KEY_HERE")>' | Out-File $sourceFile -append
	} else {
		'[assembly: Exceptionless.Configuration.Exceptionless("API_KEY_HERE")]' | Out-File $sourceFile -append
	}
}